do_fortran_indexing = 0;
a = 1;
isempty (a(logical (0)))
